@@ -1,21 +1,8 @@
-#!/usr/bin/env python
-# generate a thumbnail gallery of examples
-template = """\
-{%% extends "layout.html" %%}
-{%% set title = "Gallery" %%}
-
-
-{%% block body %%}
-
-<h3>Click on any image to see source code</h3>
-<br/>
-
-%s
-{%% endblock %%}
 """
-link_template = """\
-<a href="%s"><img src="%s" border="0" alt="%s"/></a>
+Generate a thumbnail gallery of examples.
+
 """
+from __future__ import print_function
 
 import os, glob, re, shutil, sys
 import matplotlib
@@ -32,6 +19,24 @@ static_dir = 'source/static/examples'
 pwd=os.getcwd()
 rows = []
 
+template = """
+{%% extends "layout.html" %%}
+{%% set title = "Gallery" %%}
+
+
+{%% block body %%}
+
+<h3>Click on any image to see source code</h3>
+<br/>
+
+%s
+{%% endblock %%}
+"""
+
+link_template = """
+<a href="%s"><img src="%s" border="0" alt="%s"/></a>
+"""
+
 if not os.path.exists(static_dir):
     os.makedirs(static_dir)
 
@@ -41,24 +46,29 @@ all_examples=sorted(glob.glob("*.py"))
 # check for out of date examples
 stale_examples=[]
 for example in all_examples:
-    png=example.replace('py','png')                             
+    png=example.replace('py','png')
     png_static=os.path.join(pwd,static_dir,png)
-    if (not os.path.exists(png_static) or 
+    if (not os.path.exists(png_static) or
         os.stat(png_static).st_mtime < os.stat(example).st_mtime):
         stale_examples.append(example)
 
 for example in stale_examples:
-    print example
-    png=example.replace('py','png')                             
+    print(example, end=" ")
+    png=example.replace('py','png')
     matplotlib.pyplot.figure(figsize=(6,6))
     stdout=sys.stdout
     sys.stdout=open('/dev/null','w')
-    execfile(example)
-    sys.stdout=stdout
+    try:
+        execfile(example)
+        sys.stdout=stdout
+        print(" OK")
+    except ImportError as strerr:
+        sys.stdout=stdout
+        sys.stdout.write(" FAIL: %s\n" % strerr)
+        continue
     matplotlib.pyplot.clf()
-
     im=matplotlib.image.imread(png)
-    fig = Figure(figsize=(3.0, 3.0))
+    fig = Figure(figsize=(2.5, 2.5))
     canvas = FigureCanvas(fig)
     ax = fig.add_axes([0,0,1,1], aspect='auto', frameon=False, xticks=[], yticks
 =[])
@@ -68,7 +78,7 @@ for example in stale_examples:
     fig.savefig(thumbfile)
     shutil.copy(thumbfile,os.path.join(pwd,static_dir,thumbfile))
     shutil.copy(png,os.path.join(pwd,static_dir,png))
-    
+
     basename, ext = os.path.splitext(example)
     link = '%s/%s.html'%(examples_dir, basename)
     rows.append(link_template%(link, os.path.join('_static/examples',thumbfile), basename))
