@@ -1,34 +1,9 @@
 #!/usr/bin/env python
 from nose.tools import *
-import networkx
-
-
-def florentine_families_graph():
-    G=networkx.Graph()
-    G.add_edge('Acciaiuoli','Medici')
-    G.add_edge('Castellani','Peruzzi')
-    G.add_edge('Castellani','Strozzi')
-    G.add_edge('Castellani','Barbadori')
-    G.add_edge('Medici','Barbadori')
-    G.add_edge('Medici','Ridolfi')
-    G.add_edge('Medici','Tornabuoni')
-    G.add_edge('Medici','Albizzi')
-    G.add_edge('Medici','Salviati')
-    G.add_edge('Salviati','Pazzi')
-    G.add_edge('Peruzzi','Strozzi')
-    G.add_edge('Peruzzi','Bischeri')
-    G.add_edge('Strozzi','Ridolfi')
-    G.add_edge('Strozzi','Bischeri')
-    G.add_edge('Ridolfi','Tornabuoni')
-    G.add_edge('Tornabuoni','Guadagni')
-    G.add_edge('Albizzi','Ginori')
-    G.add_edge('Albizzi','Guadagni')
-    G.add_edge('Bischeri','Guadagni')
-    G.add_edge('Guadagni','Lamberteschi')
-    return G
+import networkx as nx
 
 def weighted_G():
-    G=networkx.Graph();
+    G=nx.Graph();
     G.add_edge(0,1,weight=3)
     G.add_edge(0,2,weight=2)
     G.add_edge(0,3,weight=6)
@@ -43,13 +18,13 @@ def weighted_G():
     return G
 
 
-class TestBetweennessCentrality():
+class TestBetweennessCentrality(object):
         
     def test_K5(self):
         """Betweenness centrality: K5"""
-        G=networkx.complete_graph(5)
-        b=networkx.betweenness_centrality(G,
-                                             weighted_edges=False,
+        G=nx.complete_graph(5)
+        b=nx.betweenness_centrality(G,
+                                             weight=None,
                                              normalized=False)
         b_answer={0: 0.0, 1: 0.0, 2: 0.0, 3: 0.0, 4: 0.0}
         for n in sorted(G):
@@ -57,9 +32,9 @@ class TestBetweennessCentrality():
 
     def test_K5_endpoints(self):
         """Betweenness centrality: K5 endpoints"""
-        G=networkx.complete_graph(5)
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=False,
+        G=nx.complete_graph(5)
+        b=nx.betweenness_centrality(G,
+                                          weight=None,
                                           normalized=False,
                                           endpoints=True)
         b_answer={0: 4.0, 1: 4.0, 2: 4.0, 3: 4.0, 4: 4.0}
@@ -69,9 +44,9 @@ class TestBetweennessCentrality():
 
     def test_P3_normalized(self):
         """Betweenness centrality: P3 normalized"""
-        G=networkx.path_graph(3)
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=False,
+        G=nx.path_graph(3)
+        b=nx.betweenness_centrality(G,
+                                          weight=None,
                                           normalized=True)
         b_answer={0: 0.0, 1: 1.0, 2: 0.0}
         for n in sorted(G):
@@ -80,20 +55,20 @@ class TestBetweennessCentrality():
 
     def test_P3(self):
         """Betweenness centrality: P3"""
-        G=networkx.path_graph(3)
+        G=nx.path_graph(3)
         b_answer={0: 0.0, 1: 1.0, 2: 0.0}
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=False,
+        b=nx.betweenness_centrality(G,
+                                          weight=None,
                                           normalized=False)
         for n in sorted(G):
             assert_almost_equal(b[n],b_answer[n])
 
     def test_P3_endpoints(self):
         """Betweenness centrality: P3 endpoints"""
-        G=networkx.path_graph(3)
+        G=nx.path_graph(3)
         b_answer={0: 2.0, 1: 3.0, 2: 2.0}
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=False,
+        b=nx.betweenness_centrality(G,
+                                          weight=None,
                                           normalized=False,
                                           endpoints=True)
         for n in sorted(G):
@@ -102,13 +77,13 @@ class TestBetweennessCentrality():
 
     def test_krackhardt_kite_graph(self):
         """Betweenness centrality: Krackhardt kite graph"""
-        G=networkx.krackhardt_kite_graph()
+        G=nx.krackhardt_kite_graph()
         b_answer={0: 1.667,1: 1.667,2: 0.000,3: 7.333,4: 0.000,
                   5: 16.667,6: 16.667,7: 28.000,8: 16.000,9: 0.000}
         for b in b_answer:
             b_answer[b]/=2.0
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=False,
+        b=nx.betweenness_centrality(G,
+                                          weight=None,
                                           normalized=False)
 
         for n in sorted(G):
@@ -117,11 +92,11 @@ class TestBetweennessCentrality():
 
     def test_krackhardt_kite_graph_normalized(self):
         """Betweenness centrality: Krackhardt kite graph normalized"""
-        G=networkx.krackhardt_kite_graph()
+        G=nx.krackhardt_kite_graph()
         b_answer={0:0.023,1:0.023,2:0.000,3:0.102,4:0.000,
                   5:0.231,6:0.231,7:0.389,8:0.222,9:0.000}
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=False,
+        b=nx.betweenness_centrality(G,
+                                          weight=None,
                                           normalized=True)
 
         for n in sorted(G):
@@ -130,7 +105,7 @@ class TestBetweennessCentrality():
 
     def test_florentine_families_graph(self):
         """Betweenness centrality: Florentine families graph"""
-        G=florentine_families_graph()
+        G=nx.florentine_families_graph()
         b_answer=\
              {'Acciaiuoli':    0.000,
               'Albizzi':       0.212,
@@ -148,8 +123,8 @@ class TestBetweennessCentrality():
               'Strozzi':       0.103,
               'Tornabuoni':    0.092}
 
-        b=networkx.betweenness_centrality(G,
-                                             weighted_edges=False,
+        b=nx.betweenness_centrality(G,
+                                             weight=None,
                                              normalized=True)
         for n in sorted(G):
             assert_almost_equal(b[n],b_answer[n],places=3)
@@ -157,39 +132,39 @@ class TestBetweennessCentrality():
 
     def test_ladder_graph(self):
         """Betweenness centrality: Ladder graph"""
-        G = networkx.Graph() # ladder_graph(3)
+        G = nx.Graph() # ladder_graph(3)
         G.add_edges_from([(0,1), (0,2), (1,3), (2,3), 
                           (2,4), (4,5), (3,5)])
         b_answer={0:1.667,1: 1.667,2: 6.667,
                   3: 6.667,4: 1.667,5: 1.667}
         for b in b_answer:
             b_answer[b]/=2.0
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=False,
+        b=nx.betweenness_centrality(G,
+                                          weight=None,
                                           normalized=False)
         for n in sorted(G):
             assert_almost_equal(b[n],b_answer[n],places=3)
 
     def test_disconnected_path(self):
         """Betweenness centrality: disconnected path"""
-        G=networkx.Graph()
+        G=nx.Graph()
         G.add_path([0,1,2])
         G.add_path([3,4,5,6])
         b_answer={0:0,1:1,2:0,3:0,4:2,5:2,6:0}
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=False,
+        b=nx.betweenness_centrality(G,
+                                          weight=None,
                                           normalized=False)
         for n in sorted(G):
             assert_almost_equal(b[n],b_answer[n])
 
     def test_disconnected_path_endpoints(self):
         """Betweenness centrality: disconnected path endpoints"""
-        G=networkx.Graph()
+        G=nx.Graph()
         G.add_path([0,1,2])
         G.add_path([3,4,5,6])
         b_answer={0:2,1:3,2:2,3:3,4:5,5:5,6:3}
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=False,
+        b=nx.betweenness_centrality(G,
+                                          weight=None,
                                           normalized=False,
                                           endpoints=True)
         for n in sorted(G):
@@ -198,10 +173,10 @@ class TestBetweennessCentrality():
 
     def test_directed_path(self):
         """Betweenness centrality: directed path"""
-        G=networkx.DiGraph()
+        G=nx.DiGraph()
         G.add_path([0,1,2])
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=False,
+        b=nx.betweenness_centrality(G,
+                                          weight=None,
                                           normalized=False)
         b_answer={0: 0.0, 1: 1.0, 2: 0.0}
         for n in sorted(G):
@@ -209,10 +184,10 @@ class TestBetweennessCentrality():
 
     def test_directed_path_normalized(self):
         """Betweenness centrality: directed path normalized"""
-        G=networkx.DiGraph()
+        G=nx.DiGraph()
         G.add_path([0,1,2])
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=False,
+        b=nx.betweenness_centrality(G,
+                                          weight=None,
                                           normalized=True)
         b_answer={0: 0.0, 1: 0.5, 2: 0.0}
         for n in sorted(G):
@@ -220,13 +195,13 @@ class TestBetweennessCentrality():
 
 
 
-class TestWeightedBetweennessCentrality():
+class TestWeightedBetweennessCentrality(object):
         
     def test_K5(self):
         """Weighted betweenness centrality: K5"""
-        G=networkx.complete_graph(5)
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=True,
+        G=nx.complete_graph(5)
+        b=nx.betweenness_centrality(G,
+                                          weight='weight',
                                           normalized=False)
         b_answer={0: 0.0, 1: 0.0, 2: 0.0, 3: 0.0, 4: 0.0}
         for n in sorted(G):
@@ -234,9 +209,9 @@ class TestWeightedBetweennessCentrality():
 
     def test_P3_normalized(self):
         """Weighted betweenness centrality: P3 normalized"""
-        G=networkx.path_graph(3)
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=True,
+        G=nx.path_graph(3)
+        b=nx.betweenness_centrality(G,
+                                          weight='weight',
                                           normalized=True)
         b_answer={0: 0.0, 1: 1.0, 2: 0.0}
         for n in sorted(G):
@@ -245,24 +220,24 @@ class TestWeightedBetweennessCentrality():
 
     def test_P3(self):
         """Weighted betweenness centrality: P3"""
-        G=networkx.path_graph(3)
+        G=nx.path_graph(3)
         b_answer={0: 0.0, 1: 1.0, 2: 0.0}
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=True,
+        b=nx.betweenness_centrality(G,
+                                          weight='weight',
                                           normalized=False)
         for n in sorted(G):
             assert_almost_equal(b[n],b_answer[n])
 
     def test_krackhardt_kite_graph(self):
         """Weighted betweenness centrality: Krackhardt kite graph"""
-        G=networkx.krackhardt_kite_graph()
+        G=nx.krackhardt_kite_graph()
         b_answer={0: 1.667,1: 1.667,2: 0.000,3: 7.333,4: 0.000,
                   5: 16.667,6: 16.667,7: 28.000,8: 16.000,9: 0.000}
         for b in b_answer:
             b_answer[b]/=2.0
 
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=True,
+        b=nx.betweenness_centrality(G,
+                                          weight='weight',
                                           normalized=False)
 
         for n in sorted(G):
@@ -273,11 +248,11 @@ class TestWeightedBetweennessCentrality():
         """Weighted betweenness centrality: 
         Krackhardt kite graph normalized
         """
-        G=networkx.krackhardt_kite_graph()
+        G=nx.krackhardt_kite_graph()
         b_answer={0:0.023,1:0.023,2:0.000,3:0.102,4:0.000,
                   5:0.231,6:0.231,7:0.389,8:0.222,9:0.000}
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=True,
+        b=nx.betweenness_centrality(G,
+                                          weight='weight',
                                           normalized=True)
 
         for n in sorted(G):
@@ -287,7 +262,7 @@ class TestWeightedBetweennessCentrality():
     def test_florentine_families_graph(self):
         """Weighted betweenness centrality: 
         Florentine families graph"""
-        G=florentine_families_graph()
+        G=nx.florentine_families_graph()
         b_answer=\
              {'Acciaiuoli':    0.000,
               'Albizzi':       0.212,
@@ -305,8 +280,8 @@ class TestWeightedBetweennessCentrality():
               'Strozzi':       0.103,
               'Tornabuoni':    0.092}
 
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=True,
+        b=nx.betweenness_centrality(G,
+                                          weight='weight',
                                           normalized=True)
         for n in sorted(G):
             assert_almost_equal(b[n],b_answer[n],places=3)
@@ -314,15 +289,15 @@ class TestWeightedBetweennessCentrality():
 
     def test_ladder_graph(self):
         """Weighted betweenness centrality: Ladder graph"""
-        G = networkx.Graph() # ladder_graph(3)
+        G = nx.Graph() # ladder_graph(3)
         G.add_edges_from([(0,1), (0,2), (1,3), (2,3), 
                           (2,4), (4,5), (3,5)])
         b_answer={0:1.667,1: 1.667,2: 6.667,
                   3: 6.667,4: 1.667,5: 1.667}
         for b in b_answer:
             b_answer[b]/=2.0
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=True,
+        b=nx.betweenness_centrality(G,
+                                          weight='weight',
                                           normalized=False)
         for n in sorted(G):
             assert_almost_equal(b[n],b_answer[n],places=3)
@@ -331,15 +306,15 @@ class TestWeightedBetweennessCentrality():
         """Weighted betweenness centrality: G"""                   
         G = weighted_G()               
         b_answer={0: 2.0, 1: 0.0, 2: 4.0, 3: 3.0, 4: 4.0, 5: 0.0}
-        b=networkx.betweenness_centrality(G,
-                                          weighted_edges=True,
+        b=nx.betweenness_centrality(G,
+                                          weight='weight',
                                           normalized=False)
         for n in sorted(G):
             assert_almost_equal(b[n],b_answer[n])
 
     def test_G2(self):
         """Weighted betweenness centrality: G2"""                   
-        G=networkx.DiGraph()
+        G=nx.DiGraph()
         G.add_weighted_edges_from([('s','u',10) ,('s','x',5) ,
                                    ('u','v',1) ,('u','x',2) ,
                                    ('v','y',1) ,('x','u',3) ,
@@ -348,84 +323,88 @@ class TestWeightedBetweennessCentrality():
 
         b_answer={'y':5.0,'x':5.0,'s':4.0,'u':2.0,'v':2.0}
 
-        b=networkx.betweenness_centrality(G,
-                                             weighted_edges=True,
+        b=nx.betweenness_centrality(G,
+                                             weight='weight',
                                              normalized=False)
         for n in sorted(G):
             assert_almost_equal(b[n],b_answer[n])
 
 
-class TestEdgeBetweennessCentrality():
+class TestEdgeBetweennessCentrality(object):
         
     def test_K5(self):
         """Edge betweenness centrality: K5"""
-        G=networkx.complete_graph(5)
-        b=networkx.edge_betweenness_centrality(G,
-                                               weighted_edges=False,
-                                               normalized=False)
+        G=nx.complete_graph(5)
+        b=nx.edge_betweenness_centrality(G, weight=None, normalized=False)
         b_answer=dict.fromkeys(G.edges(),1)
         for n in sorted(G.edges()):
             assert_almost_equal(b[n],b_answer[n])
 
-    def test_C4(self):
-        """Edge betweenness centrality: C4"""
-        G=networkx.cycle_graph(4)
-        b=networkx.edge_betweenness_centrality(G,
-                                               weighted_edges=False,
-                                               normalized=False)
-        b_answer={(0, 1):2,(0, 3):2, (1, 2):2, (2, 3): 2}
+    def test_normalized_K5(self):
+        """Edge betweenness centrality: K5"""
+        G=nx.complete_graph(5)
+        b=nx.edge_betweenness_centrality(G, weight=None, normalized=True)
+        b_answer=dict.fromkeys(G.edges(),1/10.0)
         for n in sorted(G.edges()):
             assert_almost_equal(b[n],b_answer[n])
 
+
+    def test_C4(self):
+        """Edge betweenness centrality: C4"""
+        G=nx.cycle_graph(4)
+        b=nx.edge_betweenness_centrality(G, weight=None, normalized=True)
+        b_answer={(0, 1):2,(0, 3):2, (1, 2):2, (2, 3): 2}
+        for n in sorted(G.edges()):
+            assert_almost_equal(b[n],b_answer[n]/6.0)
+
     def test_P4(self):
         """Edge betweenness centrality: P4"""
-        G=networkx.path_graph(4)
-        b=networkx.edge_betweenness_centrality(G,
-                                               weighted_edges=False,
-                                               normalized=False)
+        G=nx.path_graph(4)
+        b=nx.edge_betweenness_centrality(G, weight=None, normalized=False)
         b_answer={(0, 1):3,(1, 2):4, (2, 3):3}
         for n in sorted(G.edges()):
             assert_almost_equal(b[n],b_answer[n])
 
+    def test_normalized_P4(self):
+        """Edge betweenness centrality: P4"""
+        G=nx.path_graph(4)
+        b=nx.edge_betweenness_centrality(G, weight=None, normalized=True)
+        b_answer={(0, 1):3,(1, 2):4, (2, 3):3}
+        for n in sorted(G.edges()):
+            assert_almost_equal(b[n],b_answer[n]/6.0)
+
+
     def test_balanced_tree(self):
         """Edge betweenness centrality: balanced tree"""
-        G=networkx.balanced_tree(r=2,h=2)
-        b=networkx.edge_betweenness_centrality(G,
-                                               weighted_edges=False,
-                                               normalized=False)
+        G=nx.balanced_tree(r=2,h=2)
+        b=nx.edge_betweenness_centrality(G, weight=None, normalized=False)
         b_answer={(0, 1):12,(0, 2):12,
                   (1, 3):6,(1, 4):6,(2, 5):6,(2,6):6}
         for n in sorted(G.edges()):
             assert_almost_equal(b[n],b_answer[n])
 
-class TestWeightedEdgeBetweennessCentrality():
+class TestWeightedEdgeBetweennessCentrality(object):
         
     def test_K5(self):
         """Edge betweenness centrality: K5"""
-        G=networkx.complete_graph(5)
-        b=networkx.edge_betweenness_centrality(G,
-                                               weighted_edges=True,
-                                               normalized=False)
+        G=nx.complete_graph(5)
+        b=nx.edge_betweenness_centrality(G, weight='weight', normalized=False)
         b_answer=dict.fromkeys(G.edges(),1)
         for n in sorted(G.edges()):
             assert_almost_equal(b[n],b_answer[n])
 
     def test_C4(self):
         """Edge betweenness centrality: C4"""
-        G=networkx.cycle_graph(4)
-        b=networkx.edge_betweenness_centrality(G,
-                                               weighted_edges=True,
-                                               normalized=False)
+        G=nx.cycle_graph(4)
+        b=nx.edge_betweenness_centrality(G, weight='weight', normalized=False)
         b_answer={(0, 1):2,(0, 3):2, (1, 2):2, (2, 3): 2}
         for n in sorted(G.edges()):
             assert_almost_equal(b[n],b_answer[n])
 
     def test_P4(self):
         """Edge betweenness centrality: P4"""
-        G=networkx.path_graph(4)
-        b=networkx.edge_betweenness_centrality(G,
-                                               weighted_edges=True,
-                                               normalized=False)
+        G=nx.path_graph(4)
+        b=nx.edge_betweenness_centrality(G, weight='weight', normalized=False)
         b_answer={(0, 1):3,(1, 2):4, (2, 3):3}
         for n in sorted(G.edges()):
             assert_almost_equal(b[n],b_answer[n])
@@ -433,10 +412,8 @@ class TestWeightedEdgeBetweennessCentrality():
 
     def test_balanced_tree(self):
         """Edge betweenness centrality: balanced tree"""
-        G=networkx.balanced_tree(r=2,h=2)
-        b=networkx.edge_betweenness_centrality(G,
-                                               weighted_edges=True,
-                                               normalized=False)
+        G=nx.balanced_tree(r=2,h=2)
+        b=nx.edge_betweenness_centrality(G, weight='weight', normalized=False)
         b_answer={(0, 1):12,(0, 2):12,
                   (1, 3):6,(1, 4):6,(2, 5):6,(2,6):6}
         for n in sorted(G.edges()):
@@ -446,11 +423,9 @@ class TestWeightedEdgeBetweennessCentrality():
         eList = [(0, 1, 5), (0, 2, 4), (0, 3, 3), 
                  (0, 4, 2), (1, 2, 4), (1, 3, 1), 
                  (1, 4, 3), (2, 4, 5), (3, 4, 4)]
-        G = networkx.Graph()
+        G = nx.Graph()
         G.add_weighted_edges_from(eList)
-        b = networkx.edge_betweenness_centrality(G, 
-                                                 normalized=False, 
-                                                 weighted_edges=True)
+        b = nx.edge_betweenness_centrality(G, weight='weight', normalized=False)
         b_answer={(0, 1):0.0,
                   (0, 2):1.0,
                   (0, 3):2.0,
@@ -464,3 +439,24 @@ class TestWeightedEdgeBetweennessCentrality():
         for n in sorted(G.edges()):
             assert_almost_equal(b[n],b_answer[n])
 
+    def test_normalized_weighted_graph(self):
+        eList = [(0, 1, 5), (0, 2, 4), (0, 3, 3), 
+                 (0, 4, 2), (1, 2, 4), (1, 3, 1), 
+                 (1, 4, 3), (2, 4, 5), (3, 4, 4)]
+        G = nx.Graph()
+        G.add_weighted_edges_from(eList)
+        b = nx.edge_betweenness_centrality(G, weight='weight', normalized=True)
+        b_answer={(0, 1):0.0,
+                  (0, 2):1.0,
+                  (0, 3):2.0,
+                  (0, 4):1.0,
+                  (1, 2):2.0,
+                  (1, 3):3.5,
+                  (1, 4):1.5,
+                  (2, 4):1.0,
+                  (3, 4):0.5}
+
+        norm = len(G)*(len(G)-1)/2.0
+        for n in sorted(G.edges()):
+            assert_almost_equal(b[n],b_answer[n]/norm)
+
