@@ -8,12 +8,14 @@ Draw networks with matplotlib.
 See Also
 --------
 
-matplotlib:     http://matplotlib.sourceforge.net/
+matplotlib:     http://matplotlib.org/
 
-pygraphviz:     http://networkx.lanl.gov/pygraphviz/
+pygraphviz:     http://pygraphviz.github.io/
 
 """
-#    Copyright (C) 2004-2012 by
+# Author: Aric Hagberg (hagberg@lanl.gov)
+
+#    Copyright (C) 2004-2016 by
 #    Aric Hagberg <hagberg@lanl.gov>
 #    Dan Schult <dschult@colgate.edu>
 #    Pieter Swart <swart@lanl.gov>
@@ -22,7 +24,7 @@ pygraphviz:     http://networkx.lanl.gov/pygraphviz/
 import networkx as nx
 from networkx.drawing.layout import shell_layout,\
     circular_layout,spectral_layout,spring_layout,random_layout
-__author__ = """Aric Hagberg (hagberg@lanl.gov)"""
+
 __all__ = ['draw',
            'draw_networkx',
            'draw_networkx_nodes',
@@ -36,6 +38,7 @@ __all__ = ['draw',
            'draw_shell',
            'draw_graphviz']
 
+
 def draw(G, pos=None, ax=None, hold=None, **kwds):
     """Draw the graph G with Matplotlib.
 
@@ -61,9 +64,10 @@ def draw(G, pos=None, ax=None, hold=None, **kwds):
        Set the Matplotlib hold state.  If True subsequent draw
        commands will be added to the current axes.
 
-    **kwds : optional keywords
+    kwds : optional keywords
        See networkx.draw_networkx() for a description of optional keywords.
 
+
     Examples
     --------
     >>> G=nx.dodecahedral_graph()
@@ -96,7 +100,7 @@ def draw(G, pos=None, ax=None, hold=None, **kwds):
     >>> plt.draw()  # pyplot draw()
 
     Also see the NetworkX drawing examples at
-    http://networkx.lanl.gov/gallery.html
+    http://networkx.github.io/documentation/latest/gallery.html
     """
     try:
         import matplotlib.pyplot as plt
@@ -113,17 +117,19 @@ def draw(G, pos=None, ax=None, hold=None, **kwds):
     cf.set_facecolor('w')
     if ax is None:
         if cf._axstack() is None:
-            ax=cf.add_axes((0,0,1,1))
+            ax = cf.add_axes((0, 0, 1, 1))
         else:
-            ax=cf.gca()
+            ax = cf.gca()
 
- # allow callers to override the hold state by passing hold=True|False
+    if 'with_labels' not in kwds:
+        kwds['with_labels'] = 'labels' in kwds
     b = plt.ishold()
+    # allow callers to override the hold state by passing hold=True|False
     h = kwds.pop('hold', None)
     if h is not None:
         plt.hold(h)
     try:
-        draw_networkx(G,pos=pos,ax=ax,**kwds)
+        draw_networkx(G, pos=pos, ax=ax, **kwds)
         ax.set_axis_off()
         plt.draw_if_interactive()
     except:
@@ -133,7 +139,7 @@ def draw(G, pos=None, ax=None, hold=None, **kwds):
     return
 
 
-def draw_networkx(G, pos=None, with_labels=True, **kwds):
+def draw_networkx(G, pos=None, arrows=True, with_labels=True, **kwds):
     """Draw the graph G using Matplotlib.
 
     Draw the graph with Matplotlib with options for node positions,
@@ -150,6 +156,9 @@ def draw_networkx(G, pos=None, with_labels=True, **kwds):
        If not specified a spring layout positioning will be computed.
        See networkx.layout for functions that compute node positions.
 
+    arrows : bool, optional (default=True)
+       For directed graphs, if True draw arrowheads.
+
     with_labels :  bool, optional (default=True)
        Set to True to draw labels on the nodes.
 
@@ -178,7 +187,7 @@ def draw_networkx(G, pos=None, with_labels=True, **kwds):
        marker, one of 'so^>v<dph8'.
 
     alpha : float, optional (default=1.0)
-       The node transparency
+       The node and edge transparency
 
     cmap : Matplotlib colormap, optional (default=None)
        Colormap for mapping intensities of nodes
@@ -198,7 +207,7 @@ def draw_networkx(G, pos=None, with_labels=True, **kwds):
        If numeric values are specified they will be mapped to
        colors using the edge_cmap and edge_vmin,edge_vmax parameters.
 
-    edge_ cmap : Matplotlib colormap, optional (default=None)
+    edge_cmap : Matplotlib colormap, optional (default=None)
        Colormap for mapping intensities of edges
 
     edge_vmin,edge_vmax : floats, optional (default=None)
@@ -225,6 +234,13 @@ def draw_networkx(G, pos=None, with_labels=True, **kwds):
     label : string, optional
         Label for graph legend
 
+    Notes
+    -----
+    For directed graphs, "arrows" (actually just thicker stubs) are drawn
+    at the head end.  Arrows can be turned off with keyword arrows=False.
+    Yes, it is ugly but drawing proper arrows with Matplotlib this
+    way is tricky.
+
     Examples
     --------
     >>> G=nx.dodecahedral_graph()
@@ -235,7 +251,7 @@ def draw_networkx(G, pos=None, with_labels=True, **kwds):
     >>> limits=plt.axis('off') # turn of axis
 
     Also see the NetworkX drawing examples at
-    http://networkx.lanl.gov/gallery.html
+    http://networkx.github.io/documentation/latest/gallery.html
 
     See Also
     --------
@@ -254,14 +270,15 @@ def draw_networkx(G, pos=None, with_labels=True, **kwds):
         raise
 
     if pos is None:
-        pos=nx.drawing.spring_layout(G) # default to spring layout
+        pos = nx.drawing.spring_layout(G)  # default to spring layout
 
-    node_collection=draw_networkx_nodes(G, pos, **kwds)
-    edge_collection=draw_networkx_edges(G, pos, **kwds)
+    node_collection = draw_networkx_nodes(G, pos, **kwds)
+    edge_collection = draw_networkx_edges(G, pos, arrows=arrows, **kwds)
     if with_labels:
         draw_networkx_labels(G, pos, **kwds)
     plt.draw_if_interactive()
 
+
 def draw_networkx_nodes(G, pos,
                         nodelist=None,
                         node_size=300,
@@ -273,7 +290,7 @@ def draw_networkx_nodes(G, pos,
                         vmax=None,
                         ax=None,
                         linewidths=None,
-                        label = None,
+                        label=None,
                         **kwds):
     """Draw the nodes of the graph G.
 
@@ -286,8 +303,7 @@ def draw_networkx_nodes(G, pos,
 
     pos : dictionary
        A dictionary with nodes as keys and positions as values.
-       If not specified a spring layout positioning will be computed.
-       See networkx.layout for functions that compute node positions.
+       Positions should be sequences of length 2.
 
     ax : Matplotlib Axes object, optional
        Draw the graph in the specified Matplotlib axes.
@@ -325,13 +341,18 @@ def draw_networkx_nodes(G, pos,
     label : [None| string]
        Label for legend
 
+    Returns
+    -------
+    matplotlib.collections.PathCollection
+        `PathCollection` of the nodes.
+
     Examples
     --------
     >>> G=nx.dodecahedral_graph()
     >>> nodes=nx.draw_networkx_nodes(G,pos=nx.spring_layout(G))
 
     Also see the NetworkX drawing examples at
-    http://networkx.lanl.gov/gallery.html
+    http://networkx.github.io/documentation/latest/gallery.html
 
     See Also
     --------
@@ -350,35 +371,32 @@ def draw_networkx_nodes(G, pos,
         print("Matplotlib unable to open display")
         raise
 
-
     if ax is None:
-        ax=plt.gca()
+        ax = plt.gca()
 
     if nodelist is None:
-        nodelist=G.nodes()
+        nodelist = G.nodes()
 
-    if not nodelist or len(nodelist)==0:  # empty nodelist, no drawing
+    if not nodelist or len(nodelist) == 0:  # empty nodelist, no drawing
         return None
 
     try:
-        xy=numpy.asarray([pos[v] for v in nodelist])
+        xy = numpy.asarray([pos[v] for v in nodelist])
     except KeyError as e:
         raise nx.NetworkXError('Node %s has no position.'%e)
     except ValueError:
         raise nx.NetworkXError('Bad value in node positions.')
 
-
-
-    node_collection=ax.scatter(xy[:,0], xy[:,1],
-                               s=node_size,
-                               c=node_color,
-                               marker=node_shape,
-                               cmap=cmap,
-                               vmin=vmin,
-                               vmax=vmax,
-                               alpha=alpha,
-                               linewidths=linewidths,
-                               label=label)
+    node_collection = ax.scatter(xy[:, 0], xy[:, 1],
+                                 s=node_size,
+                                 c=node_color,
+                                 marker=node_shape,
+                                 cmap=cmap,
+                                 vmin=vmin,
+                                 vmax=vmax,
+                                 alpha=alpha,
+                                 linewidths=linewidths,
+                                 label=label)
 
     node_collection.set_zorder(2)
     return node_collection
@@ -389,7 +407,7 @@ def draw_networkx_edges(G, pos,
                         width=1.0,
                         edge_color='k',
                         style='solid',
-                        alpha=None,
+                        alpha=1.0,
                         edge_cmap=None,
                         edge_vmin=None,
                         edge_vmax=None,
@@ -408,14 +426,13 @@ def draw_networkx_edges(G, pos,
 
     pos : dictionary
        A dictionary with nodes as keys and positions as values.
-       If not specified a spring layout positioning will be computed.
-       See networkx.layout for functions that compute node positions.
+       Positions should be sequences of length 2.
 
     edgelist : collection of edge tuples
        Draw only specified edges(default=G.edges())
 
-    width : float
-       Line width of edges (default =1.0)
+    width : float, or array of floats
+       Line width of edges (default=1.0)
 
     edge_color : color string, or array of floats
        Edge color. Can be a single color format string (default='r'),
@@ -444,6 +461,11 @@ def draw_networkx_edges(G, pos,
     label : [None| string]
        Label for legend
 
+    Returns
+    -------
+    matplotlib.collection.LineCollection
+        `LineCollection` of the edges
+
     Notes
     -----
     For directed graphs, "arrows" (actually just thicker stubs) are drawn
@@ -457,7 +479,7 @@ def draw_networkx_edges(G, pos,
     >>> edges=nx.draw_networkx_edges(G,pos=nx.spring_layout(G))
 
     Also see the NetworkX drawing examples at
-    http://networkx.lanl.gov/gallery.html
+    http://networkx.github.io/documentation/latest/gallery.html
 
     See Also
     --------
@@ -471,7 +493,7 @@ def draw_networkx_edges(G, pos,
         import matplotlib
         import matplotlib.pyplot as plt
         import matplotlib.cbook as cb
-        from matplotlib.colors import colorConverter,Colormap
+        from matplotlib.colors import colorConverter, Colormap
         from matplotlib.collections import LineCollection
         import numpy
     except ImportError:
@@ -481,16 +503,16 @@ def draw_networkx_edges(G, pos,
         raise
 
     if ax is None:
-        ax=plt.gca()
+        ax = plt.gca()
 
     if edgelist is None:
-        edgelist=G.edges()
+        edgelist = G.edges()
 
-    if not edgelist or len(edgelist)==0: # no edges!
+    if not edgelist or len(edgelist) == 0:  # no edges!
         return None
 
     # set edge positions
-    edge_pos=numpy.asarray([(pos[e[0]],pos[e[1]]) for e in edgelist])
+    edge_pos = numpy.asarray([(pos[e[0]], pos[e[1]]) for e in edgelist])
 
     if not cb.iterable(width):
         lw = (width,)
@@ -499,17 +521,17 @@ def draw_networkx_edges(G, pos,
 
     if not cb.is_string_like(edge_color) \
            and cb.iterable(edge_color) \
-           and len(edge_color)==len(edge_pos):
+           and len(edge_color) == len(edge_pos):
         if numpy.alltrue([cb.is_string_like(c)
                          for c in edge_color]):
             # (should check ALL elements)
             # list of color letters such as ['k','r','k',...]
-            edge_colors = tuple([colorConverter.to_rgba(c,alpha)
+            edge_colors = tuple([colorConverter.to_rgba(c, alpha)
                                  for c in edge_color])
         elif numpy.alltrue([not cb.is_string_like(c)
                            for c in edge_color]):
             # If color specs are given as (rgb) or (rgba) tuples, we're OK
-            if numpy.alltrue([cb.iterable(c) and len(c) in (3,4)
+            if numpy.alltrue([cb.iterable(c) and len(c) in (3, 4)
                              for c in edge_color]):
                 edge_colors = tuple(edge_color)
             else:
@@ -518,21 +540,20 @@ def draw_networkx_edges(G, pos,
         else:
             raise ValueError('edge_color must consist of either color names or numbers')
     else:
-        if cb.is_string_like(edge_color) or len(edge_color)==1:
-            edge_colors = ( colorConverter.to_rgba(edge_color, alpha), )
+        if cb.is_string_like(edge_color) or len(edge_color) == 1:
+            edge_colors = (colorConverter.to_rgba(edge_color, alpha), )
         else:
             raise ValueError('edge_color must be a single color or list of exactly m colors where m is the number or edges')
 
     edge_collection = LineCollection(edge_pos,
-                                     colors       = edge_colors,
-                                     linewidths   = lw,
-                                     antialiaseds = (1,),
-                                     linestyle    = style,
+                                     colors=edge_colors,
+                                     linewidths=lw,
+                                     antialiaseds=(1,),
+                                     linestyle=style,
                                      transOffset = ax.transData,
                                      )
 
-
-    edge_collection.set_zorder(1) # edges go behind nodes
+    edge_collection.set_zorder(1)  # edges go behind nodes
     edge_collection.set_label(label)
     ax.add_collection(edge_collection)
 
@@ -554,7 +575,7 @@ def draw_networkx_edges(G, pos,
         else:
             edge_collection.autoscale()
 
-    arrow_collection=None
+    arrow_collection = None
 
     if G.is_directed() and arrows:
 
@@ -562,52 +583,51 @@ def draw_networkx_edges(G, pos,
         # draw thick line segments at head end of edge
         # waiting for someone else to implement arrows that will work
         arrow_colors = edge_colors
-        a_pos=[]
-        p=1.0-0.25 # make head segment 25 percent of edge length
-        for src,dst in edge_pos:
-            x1,y1=src
-            x2,y2=dst
-            dx=x2-x1 # x offset
-            dy=y2-y1 # y offset
-            d=numpy.sqrt(float(dx**2+dy**2)) # length of edge
-            if d==0: # source and target at same position
+        a_pos = []
+        p = 1.0-0.25  # make head segment 25 percent of edge length
+        for src, dst in edge_pos:
+            x1, y1 = src
+            x2, y2 = dst
+            dx = x2-x1   # x offset
+            dy = y2-y1   # y offset
+            d = numpy.sqrt(float(dx**2 + dy**2))  # length of edge
+            if d == 0:   # source and target at same position
                 continue
-            if dx==0: # vertical edge
-                xa=x2
-                ya=dy*p+y1
-            if dy==0: # horizontal edge
-                ya=y2
-                xa=dx*p+x1
+            if dx == 0:  # vertical edge
+                xa = x2
+                ya = dy*p+y1
+            if dy == 0:  # horizontal edge
+                ya = y2
+                xa = dx*p+x1
             else:
-                theta=numpy.arctan2(dy,dx)
-                xa=p*d*numpy.cos(theta)+x1
-                ya=p*d*numpy.sin(theta)+y1
+                theta = numpy.arctan2(dy, dx)
+                xa = p*d*numpy.cos(theta)+x1
+                ya = p*d*numpy.sin(theta)+y1
 
-            a_pos.append(((xa,ya),(x2,y2)))
+            a_pos.append(((xa, ya), (x2, y2)))
 
         arrow_collection = LineCollection(a_pos,
-                                colors       = arrow_colors,
-                                linewidths   = [4*ww for ww in lw],
-                                antialiaseds = (1,),
+                                colors=arrow_colors,
+                                linewidths=[4*ww for ww in lw],
+                                antialiaseds=(1,),
                                 transOffset = ax.transData,
                                 )
 
-        arrow_collection.set_zorder(1) # edges go behind nodes
+        arrow_collection.set_zorder(1)  # edges go behind nodes
         arrow_collection.set_label(label)
         ax.add_collection(arrow_collection)
 
-
     # update view
-    minx = numpy.amin(numpy.ravel(edge_pos[:,:,0]))
-    maxx = numpy.amax(numpy.ravel(edge_pos[:,:,0]))
-    miny = numpy.amin(numpy.ravel(edge_pos[:,:,1]))
-    maxy = numpy.amax(numpy.ravel(edge_pos[:,:,1]))
+    minx = numpy.amin(numpy.ravel(edge_pos[:, :, 0]))
+    maxx = numpy.amax(numpy.ravel(edge_pos[:, :, 0]))
+    miny = numpy.amin(numpy.ravel(edge_pos[:, :, 1]))
+    maxy = numpy.amax(numpy.ravel(edge_pos[:, :, 1]))
 
     w = maxx-minx
     h = maxy-miny
-    padx, pady = 0.05*w, 0.05*h
+    padx,  pady = 0.05*w, 0.05*h
     corners = (minx-padx, miny-pady), (maxx+padx, maxy+pady)
-    ax.update_datalim( corners)
+    ax.update_datalim(corners)
     ax.autoscale_view()
 
 #    if arrow_collection:
@@ -622,6 +642,7 @@ def draw_networkx_labels(G, pos,
                          font_family='sans-serif',
                          font_weight='normal',
                          alpha=1.0,
+                         bbox=None,
                          ax=None,
                          **kwds):
     """Draw node labels on the graph G.
@@ -631,10 +652,9 @@ def draw_networkx_labels(G, pos,
     G : graph
        A networkx graph
 
-    pos : dictionary, optional
+    pos : dictionary
        A dictionary with nodes as keys and positions as values.
-       If not specified a spring layout positioning will be computed.
-       See networkx.layout for functions that compute node positions.
+       Positions should be sequences of length 2.
 
     labels : dictionary, optional (default=None)
        Node labels in a dictionary keyed by node of text labels
@@ -657,6 +677,10 @@ def draw_networkx_labels(G, pos,
     ax : Matplotlib Axes object, optional
        Draw the graph in the specified Matplotlib axes.
 
+    Returns
+    -------
+    dict
+        `dict` of labels keyed on the nodes
 
     Examples
     --------
@@ -664,7 +688,7 @@ def draw_networkx_labels(G, pos,
     >>> labels=nx.draw_networkx_labels(G,pos=nx.spring_layout(G))
 
     Also see the NetworkX drawing examples at
-    http://networkx.lanl.gov/gallery.html
+    http://networkx.github.io/documentation/latest/gallery.html
 
 
     See Also
@@ -685,21 +709,21 @@ def draw_networkx_labels(G, pos,
         raise
 
     if ax is None:
-        ax=plt.gca()
+        ax = plt.gca()
 
     if labels is None:
-        labels=dict( (n,n) for n in G.nodes())
+        labels = dict((n, n) for n in G.nodes())
 
     # set optional alignment
-    horizontalalignment=kwds.get('horizontalalignment','center')
-    verticalalignment=kwds.get('verticalalignment','center')
+    horizontalalignment = kwds.get('horizontalalignment', 'center')
+    verticalalignment = kwds.get('verticalalignment', 'center')
 
-    text_items={}  # there is no text collection so we'll fake one
+    text_items = {}  # there is no text collection so we'll fake one
     for n, label in labels.items():
-        (x,y)=pos[n]
+        (x, y) = pos[n]
         if not cb.is_string_like(label):
-            label=str(label) # this will cause "1" and 1 to be labeled the same
-        t=ax.text(x, y,
+            label = str(label)  # this will cause "1" and 1 to be labeled the same
+        t = ax.text(x, y,
                   label,
                   size=font_size,
                   color=font_color,
@@ -707,13 +731,15 @@ def draw_networkx_labels(G, pos,
                   weight=font_weight,
                   horizontalalignment=horizontalalignment,
                   verticalalignment=verticalalignment,
-                  transform = ax.transData,
+                  transform=ax.transData,
+                  bbox=bbox,
                   clip_on=True,
                   )
-        text_items[n]=t
+        text_items[n] = t
 
     return text_items
 
+
 def draw_networkx_edge_labels(G, pos,
                               edge_labels=None,
                               label_pos=0.5,
@@ -733,10 +759,9 @@ def draw_networkx_edge_labels(G, pos,
     G : graph
        A networkx graph
 
-    pos : dictionary, optional
+    pos : dictionary
        A dictionary with nodes as keys and positions as values.
-       If not specified a spring layout positioning will be computed.
-       See networkx.layout for functions that compute node positions.
+       Positions should be sequences of length 2.
 
     ax : Matplotlib Axes object, optional
        Draw the graph in the specified Matplotlib axes.
@@ -770,13 +795,18 @@ def draw_networkx_edge_labels(G, pos,
     clip_on : bool
        Turn on clipping at axis boundaries (default=True)
 
+    Returns
+    -------
+    dict
+        `dict` of labels keyed on the edges
+
     Examples
     --------
     >>> G=nx.dodecahedral_graph()
     >>> edge_labels=nx.draw_networkx_edge_labels(G,pos=nx.spring_layout(G))
 
     Also see the NetworkX drawing examples at
-    http://networkx.lanl.gov/gallery.html
+    http://networkx.github.io/documentation/latest/gallery.html
 
     See Also
     --------
@@ -797,31 +827,31 @@ def draw_networkx_edge_labels(G, pos,
         raise
 
     if ax is None:
-        ax=plt.gca()
+        ax = plt.gca()
     if edge_labels is None:
-        labels=dict( ((u,v), d) for u,v,d in G.edges(data=True) )
+        labels = dict(((u, v), d) for u, v, d in G.edges(data=True))
     else:
         labels = edge_labels
-    text_items={}
-    for (n1,n2), label in labels.items():
-        (x1,y1)=pos[n1]
-        (x2,y2)=pos[n2]
-        (x,y) = (x1 * label_pos + x2 * (1.0 - label_pos),
-                 y1 * label_pos + y2 * (1.0 - label_pos))
+    text_items = {}
+    for (n1, n2), label in labels.items():
+        (x1, y1) = pos[n1]
+        (x2, y2) = pos[n2]
+        (x, y) = (x1 * label_pos + x2 * (1.0 - label_pos),
+                  y1 * label_pos + y2 * (1.0 - label_pos))
 
         if rotate:
-            angle=numpy.arctan2(y2-y1,x2-x1)/(2.0*numpy.pi)*360 # degrees
+            angle = numpy.arctan2(y2-y1, x2-x1)/(2.0*numpy.pi)*360  # degrees
             # make label orientation "right-side-up"
             if angle > 90:
-                angle-=180
+                angle -= 180
             if angle < - 90:
-                angle+=180
+                angle += 180
             # transform data coordinate angle to screen coordinate angle
-            xy=numpy.array((x,y))
-            trans_angle=ax.transData.transform_angles(numpy.array((angle,)),
-                                                      xy.reshape((1,2)))[0]
+            xy = numpy.array((x, y))
+            trans_angle = ax.transData.transform_angles(numpy.array((angle,)),
+                                                        xy.reshape((1, 2)))[0]
         else:
-            trans_angle=0.0
+            trans_angle = 0.0
         # use default box of white with white border
         if bbox is None:
             bbox = dict(boxstyle='round',
@@ -829,68 +859,143 @@ def draw_networkx_edge_labels(G, pos,
                         fc=(1.0, 1.0, 1.0),
                         )
         if not cb.is_string_like(label):
-            label=str(label) # this will cause "1" and 1 to be labeled the same
+            label = str(label)  # this will cause "1" and 1 to be labeled the same
 
         # set optional alignment
-        horizontalalignment=kwds.get('horizontalalignment','center')
-        verticalalignment=kwds.get('verticalalignment','center')
+        horizontalalignment = kwds.get('horizontalalignment', 'center')
+        verticalalignment = kwds.get('verticalalignment', 'center')
 
-        t=ax.text(x, y,
-                  label,
-                  size=font_size,
-                  color=font_color,
-                  family=font_family,
-                  weight=font_weight,
-                  horizontalalignment=horizontalalignment,
-                  verticalalignment=verticalalignment,
-                  rotation=trans_angle,
-                  transform = ax.transData,
-                  bbox = bbox,
-                  zorder = 1,
-                  clip_on=True,
-                  )
-        text_items[(n1,n2)]=t
+        t = ax.text(x, y,
+                    label,
+                    size=font_size,
+                    color=font_color,
+                    family=font_family,
+                    weight=font_weight,
+                    horizontalalignment=horizontalalignment,
+                    verticalalignment=verticalalignment,
+                    rotation=trans_angle,
+                    transform=ax.transData,
+                    bbox=bbox,
+                    zorder=1,
+                    clip_on=True,
+                    )
+        text_items[(n1, n2)] = t
 
     return text_items
 
+
 def draw_circular(G, **kwargs):
-    """Draw the graph G with a circular layout."""
-    draw(G,circular_layout(G),**kwargs)
+    """Draw the graph G with a circular layout.
+
+    Parameters
+    ----------
+    G : graph
+       A networkx graph
+
+    kwargs : optional keywords
+       See networkx.draw_networkx() for a description of optional keywords,
+       with the exception of the pos parameter which is not used by this
+       function.
+    """
+    draw(G, circular_layout(G), **kwargs)
+
 
 def draw_random(G, **kwargs):
-    """Draw the graph G with a random layout."""
-    draw(G,random_layout(G),**kwargs)
+    """Draw the graph G with a random layout.
+
+    Parameters
+    ----------
+    G : graph
+       A networkx graph
+
+    kwargs : optional keywords
+       See networkx.draw_networkx() for a description of optional keywords,
+       with the exception of the pos parameter which is not used by this
+       function.
+    """
+    draw(G, random_layout(G), **kwargs)
+
 
 def draw_spectral(G, **kwargs):
-    """Draw the graph G with a spectral layout."""
-    draw(G,spectral_layout(G),**kwargs)
+    """Draw the graph G with a spectral layout.
+
+    Parameters
+    ----------
+    G : graph
+       A networkx graph
+
+    kwargs : optional keywords
+       See networkx.draw_networkx() for a description of optional keywords,
+       with the exception of the pos parameter which is not used by this
+       function.
+    """
+    draw(G, spectral_layout(G), **kwargs)
+
 
 def draw_spring(G, **kwargs):
-    """Draw the graph G with a spring layout."""
-    draw(G,spring_layout(G),**kwargs)
+    """Draw the graph G with a spring layout.
+
+    Parameters
+    ----------
+    G : graph
+       A networkx graph
+
+    kwargs : optional keywords
+       See networkx.draw_networkx() for a description of optional keywords,
+       with the exception of the pos parameter which is not used by this
+       function.
+    """
+    draw(G, spring_layout(G), **kwargs)
+
 
 def draw_shell(G, **kwargs):
-    """Draw networkx graph with shell layout."""
+    """Draw networkx graph with shell layout.
+
+    Parameters
+    ----------
+    G : graph
+       A networkx graph
+
+    kwargs : optional keywords
+       See networkx.draw_networkx() for a description of optional keywords,
+       with the exception of the pos parameter which is not used by this
+       function.
+    """
     nlist = kwargs.get('nlist', None)
-    if nlist != None:
+    if nlist is not None:
         del(kwargs['nlist'])
-    draw(G,shell_layout(G,nlist=nlist),**kwargs)
+    draw(G, shell_layout(G, nlist=nlist), **kwargs)
+
 
 def draw_graphviz(G, prog="neato", **kwargs):
-    """Draw networkx graph with graphviz layout."""
-    pos=nx.drawing.graphviz_layout(G,prog)
-    draw(G,pos,**kwargs)
+    """Draw networkx graph with graphviz layout.
 
-def draw_nx(G,pos,**kwds):
+    Parameters
+    ----------
+    G : graph
+       A networkx graph
+
+    prog : string, optional
+      Name of Graphviz layout program
+
+    kwargs : optional keywords
+       See networkx.draw_networkx() for a description of optional keywords.
+    """
+    pos = nx.drawing.graphviz_layout(G, prog)
+    draw(G, pos, **kwargs)
+
+
+def draw_nx(G, pos, **kwds):
     """For backward compatibility; use draw or draw_networkx."""
-    draw(G,pos,**kwds)
+    draw(G, pos, **kwds)
+
 
 # fixture for nose tests
 def setup_module(module):
     from nose import SkipTest
     try:
         import matplotlib as mpl
-        mpl.use('PS',warn=False)
+        mpl.use('PS', warn=False)
         import matplotlib.pyplot as plt
     except:
         raise SkipTest("matplotlib not available")
