@@ -6,24 +6,29 @@ The typical graph generator is called as follows:
 >>> G=nx.complete_graph(100)
 
 returning the complete graph on n nodes labeled 0,..,99
-as a simple graph. Except for empty_graph, all the generators 
+as a simple graph. Except for empty_graph, all the generators
 in this module return a Graph class (i.e. a simple, undirected graph).
 
 """
-#    Copyright (C) 2004-2010 by 
+#    Copyright (C) 2004-2015 by
 #    Aric Hagberg <hagberg@lanl.gov>
 #    Dan Schult <dschult@colgate.edu>
 #    Pieter Swart <swart@lanl.gov>
 #    All rights reserved.
 #    BSD license.
 import itertools
+
+from networkx.algorithms.bipartite.generators import complete_bipartite_graph
+from networkx.utils import accumulate
+
 __author__ ="""Aric Hagberg (hagberg@lanl.gov)\nPieter Swart (swart@lanl.gov)"""
 
 __all__ = [ 'balanced_tree',
             'barbell_graph',
             'complete_graph',
-            'complete_bipartite_graph',
+            'complete_multipartite_graph',
             'circular_ladder_graph',
+            'circulant_graph',
             'cycle_graph',
             'dorogovtsev_goltsev_mendes_graph',
             'empty_graph',
@@ -62,7 +67,7 @@ def _tree_edges(n,r):
                 break
 
 def full_rary_tree(r, n, create_using=None):
-    """Creates a full r-ary tree of n vertices. 
+    """Creates a full r-ary tree of n vertices.
 
     Sometimes called a k-ary, n-ary, or m-ary tree.  "... all non-leaf
     vertices have exactly r children and all levels are full except
@@ -77,7 +82,7 @@ def full_rary_tree(r, n, create_using=None):
     n : int
         Number of nodes in the tree
     create_using : NetworkX graph type, optional
-        Use specified type to construct graph (default = networkx.Graph)    
+        Use specified type to construct graph (default = networkx.Graph)
 
     Returns
     -------
@@ -103,7 +108,7 @@ def balanced_tree(r, h, create_using=None):
     h : int
         Height of the tree
     create_using : NetworkX graph type, optional
-        Use specified type to construct graph (default = networkx.Graph)    
+        Use specified type to construct graph (default = networkx.Graph)
 
     Returns
     -------
@@ -163,7 +168,7 @@ def barbell_graph(m1,m2,create_using=None):
     # left barbell
     G=complete_graph(m1,create_using)
     G.name="barbell_graph(%d,%d)"%(m1,m2)
-    
+
     # connecting path
     G.add_nodes_from([v for v in range(m1,m1+m2-1)])
     if m2>1:
@@ -177,8 +182,8 @@ def barbell_graph(m1,m2,create_using=None):
     return G
 
 def complete_graph(n,create_using=None):
-    """ Return the complete graph K_n with n nodes. 
-    
+    """ Return the complete graph K_n with n nodes.
+
     Node labels are the integers 0 to n-1.
     """
     G=empty_graph(n,create_using)
@@ -192,25 +197,6 @@ def complete_graph(n,create_using=None):
     return G
 
 
-def complete_bipartite_graph(n1,n2,create_using=None):
-    """Return the complete bipartite graph K_{n1_n2}.
-    
-    Composed of two partitions with n1 nodes in the first 
-    and n2 nodes in the second. Each node in the first is 
-    connected to each node in the second.
-
-    Node labels are the integers 0 to n1+n2-1
-    
-    """
-    if create_using is not None and create_using.is_directed():
-        raise nx.NetworkXError("Directed Graph not supported")
-    G=empty_graph(n1+n2,create_using)
-    G.name="complete_bipartite_graph(%d,%d)"%(n1,n2)
-    for v1 in range(n1):
-        for v2 in range(n2):
-            G.add_edge(v1,n1+v2)
-    return G
-
 def circular_ladder_graph(n,create_using=None):
     """Return the circular ladder graph CL_n of length n.
 
@@ -218,7 +204,7 @@ def circular_ladder_graph(n,create_using=None):
     each of the n pairs of concentric nodes are joined by an edge.
 
     Node labels are the integers 0 to n-1
-    
+
     """
     G=ladder_graph(n,create_using)
     G.name="circular_ladder_graph(%d)"%n
@@ -226,14 +212,69 @@ def circular_ladder_graph(n,create_using=None):
     G.add_edge(n,2*n-1)
     return G
 
+
+def circulant_graph(n, offsets, create_using=None):
+    """Generates the circulant graph Ci_n(x_1, x_2, ..., x_m) with n vertices.
+
+    Returns
+    -------
+    The graph Ci_n(x_1, ..., x_m) consisting of n vertices 0, ..., n-1 such
+    that the vertex with label i is connected to the vertices labelled (i + x)
+    and (i - x), for all x in x_1 up to x_m, with the indices taken modulo n.
+
+    Parameters
+    ----------
+    n : integer
+        The number of vertices the generated graph is to contain.
+    offsets : list of integers
+        A list of vertex offsets, x_1 up to x_m, as described above.
+    create_using : NetworkX graph type, optional
+        Use specified type to construct graph (default = networkx.Graph)
+
+    Examples
+    --------
+    Many well-known graph families are subfamilies of the circulant graphs; for
+    example, to generate the cycle graph on n points, we connect every vertex to
+    every other at offset plus or minus one. For n = 10,
+
+    >>> import networkx
+    >>> G = networkx.generators.classic.circulant_graph(10, [1])
+    >>> edges = [
+    ...     (0, 9), (0, 1), (1, 2), (2, 3), (3, 4),
+    ...     (4, 5), (5, 6), (6, 7), (7, 8), (8, 9)]
+    ...
+    >>> sorted(edges) == sorted(G.edges())
+    True
+
+    Similarly, we can generate the complete graph on 5 points with the set of
+    offsets [1, 2]:
+
+    >>> G = networkx.generators.classic.circulant_graph(5, [1, 2])
+    >>> edges = [
+    ...     (0, 1), (0, 2), (0, 3), (0, 4), (1, 2),
+    ...     (1, 3), (1, 4), (2, 3), (2, 4), (3, 4)]
+    ...
+    >>> sorted(edges) == sorted(G.edges())
+    True
+
+    """
+    G = empty_graph(n, create_using)
+    template = 'circulant_graph(%d, [%s])'
+    G.name = template % (n, ', '.join(str(j) for j in offsets))
+    for i in range(n):
+        for j in offsets:
+            G.add_edge(i, (i - j) % n)
+            G.add_edge(i, (i + j) % n)
+    return G
+
 def cycle_graph(n,create_using=None):
     """Return the cycle graph C_n over n nodes.
-   
+
     C_n is the n-path with two end-nodes connected.
 
     Node labels are the integers 0 to n-1
     If create_using is a DiGraph, the direction is in increasing order.
-    
+
     """
     G=path_graph(n,create_using)
     G.name="cycle_graph(%d)"%n
@@ -245,7 +286,7 @@ def dorogovtsev_goltsev_mendes_graph(n,create_using=None):
 
     n is the generation.
     See: arXiv:/cond-mat/0112143 by Dorogovtsev, Goltsev and Mendes.
-    
+
     """
     if create_using is not None:
         if create_using.is_directed():
@@ -278,13 +319,13 @@ def empty_graph(n=0,create_using=None):
     10
     >>> G.number_of_edges()
     0
- 
+
     The variable create_using should point to a "graph"-like object that
     will be cleaned (nodes and edges will be removed) and refitted as
     an empty "graph" with n nodes with integer labels. This capability
     is useful for specifying the class-nature of the resulting empty
     "graph" (i.e. Graph, DiGraph, MyWeirdGraphClass, etc.).
-    
+
     The variable create_using has two main uses:
     Firstly, the variable create_using can be used to create an
     empty digraph, network,etc.  For example,
@@ -302,7 +343,7 @@ def empty_graph(n=0,create_using=None):
     graph (resp. digraph, pseudograph, etc.).
 
     See also create_empty_copy(G).
-    
+
     """
     if create_using is None:
         # default empty graph is a simple graph
@@ -312,7 +353,7 @@ def empty_graph(n=0,create_using=None):
         G.clear()
 
     G.add_nodes_from(range(n))
-    G.name="empty_graph(%d)"%n 
+    G.name="empty_graph(%d)"%n
     return G
 
 def grid_2d_graph(m,n,periodic=False,create_using=None):
@@ -354,7 +395,7 @@ def grid_graph(dim,periodic=False):
 
     If periodic=True then join grid edges with periodic boundary conditions.
 
-    """    
+    """
     dlabel="%s"%dim
     if dim==[]:
         G=empty_graph(0)
@@ -364,7 +405,7 @@ def grid_graph(dim,periodic=False):
         raise nx.NetworkXError("dim is not a list of integers")
     if min(dim)<=0:
         raise nx.NetworkXError(\
-              "dim is not a list of strictly positive integers")      
+              "dim is not a list of strictly positive integers")
     if periodic:
         func=cycle_graph
     else:
@@ -374,11 +415,11 @@ def grid_graph(dim,periodic=False):
     current_dim=dim.pop()
     G=func(current_dim)
     while len(dim)>0:
-        current_dim=dim.pop() 
+        current_dim=dim.pop()
         # order matters: copy before it is cleared during the creation of Gnew
-        Gold=G.copy() 
+        Gold=G.copy()
         Gnew=func(current_dim)
-        # explicit: create_using=None 
+        # explicit: create_using=None
         # This is so that we get a new graph of Gnew's class.
         G=nx.cartesian_product(Gnew,Gold)
     # graph G is done but has labels of the form (1,(2,(3,1)))
@@ -405,33 +446,33 @@ def ladder_graph(n,create_using=None):
     each pair connected by a single edge.
 
     Node labels are the integers 0 to 2*n - 1.
-    
+
     """
     if create_using is not None and create_using.is_directed():
         raise nx.NetworkXError("Directed Graph not supported")
     G=empty_graph(2*n,create_using)
-    G.name="ladder_graph_(%d)"%n 
+    G.name="ladder_graph_(%d)"%n
     G.add_edges_from([(v,v+1) for v in range(n-1)])
     G.add_edges_from([(v,v+1) for v in range(n,2*n-1)])
     G.add_edges_from([(v,v+n) for v in range(n)])
     return G
 
 def lollipop_graph(m,n,create_using=None):
-    """Return the Lollipop Graph; K_m connected to P_n.
+    """Return the Lollipop Graph; `K_m` connected to `P_n`.
 
     This is the Barbell Graph without the right barbell.
 
-    For m>1 and n>=0, the complete graph K_m is connected to the 
+    For m>1 and n>=0, the complete graph K_m is connected to the
     path P_n.  The resulting m+n nodes are labelled 0,...,m-1 for the
     complete graph and m,...,m+n-1 for the path. The 2 subgraphs
-    are joined via the edge (m-1,m).  If n=0, this is merely a complete 
+    are joined via the edge (m-1,m).  If n=0, this is merely a complete
     graph.
 
     Node labels are the integers 0 to number_of_nodes - 1.
 
     (This graph is an extremal example in David Aldous and Jim
     Fill's etext on Random Walks on Graphs.)
-    
+
     """
     if create_using is not None and create_using.is_directed():
         raise nx.NetworkXError("Directed Graph not supported")
@@ -452,8 +493,9 @@ def lollipop_graph(m,n,create_using=None):
     G.name="lollipop_graph(%d,%d)"%(m,n)
     return G
 
+
 def null_graph(create_using=None):
-    """ Return the Null graph with no nodes or edges. 
+    """Return the Null graph with no nodes or edges.
 
     See empty_graph for the use of create_using.
 
@@ -466,7 +508,7 @@ def path_graph(n,create_using=None):
     """Return the Path graph P_n of n nodes linearly connected by n-1 edges.
 
     Node labels are the integers 0 to n - 1.
-    If create_using is a DiGraph then the edges are directed in 
+    If create_using is a DiGraph then the edges are directed in
     increasing order.
 
     """
@@ -494,11 +536,13 @@ def trivial_graph(create_using=None):
     return G
 
 def wheel_graph(n,create_using=None):
-    """ Return the wheel graph: a single hub node connected to each node of the (n-1)-node cycle graph. 
+    """ Return the wheel graph: a single hub node connected to each node of the (n-1)-node cycle graph.
 
    Node labels are the integers 0 to n - 1.
 
     """
+    if n == 0:
+        return nx.empty_graph(n, create_using=create_using)
     G=star_graph(n-1,create_using)
     G.name="wheel_graph(%d)"%n
     G.add_edges_from([(v,v+1) for v in range(1,n-1)])
@@ -506,3 +550,75 @@ def wheel_graph(n,create_using=None):
         G.add_edge(1,n-1)
     return G
 
+
+def complete_multipartite_graph(*block_sizes):
+    """Returns the complete multipartite graph with the specified block sizes.
+
+    Parameters
+    ----------
+
+    block_sizes : tuple of integers
+
+       The number of vertices in each block of the multipartite graph. The
+       length of this tuple is the number of blocks.
+
+    Returns
+    -------
+
+    G : NetworkX Graph
+
+       Returns the complete multipartite graph with the specified block sizes.
+
+       For each node, the node attribute ``'block'`` is an integer indicating
+       which block contains the node.
+
+    Examples
+    --------
+
+    Creating a complete tripartite graph, with blocks of one, two, and three
+    vertices, respectively.
+
+        >>> import networkx as nx
+        >>> G = nx.complete_multipartite_graph(1, 2, 3)
+        >>> [G.node[u]['block'] for u in G]
+        [0, 1, 1, 2, 2, 2]
+        >>> G.edges(0)
+        [(0, 1), (0, 2), (0, 3), (0, 4), (0, 5)]
+        >>> G.edges(2)
+        [(2, 0), (2, 3), (2, 4), (2, 5)]
+        >>> G.edges(4)
+        [(4, 0), (4, 1), (4, 2)]
+
+    Notes
+    -----
+
+    This function generalizes several other graph generator functions.
+
+    - If no block sizes are given, this returns the null graph.
+    - If a single block size ``n`` is given, this returns the empty graph on
+      ``n`` nodes.
+    - If two block sizes ``m`` and ``n`` are given, this returns the complete
+      bipartite graph on ``m + n`` nodes.
+    - If block sizes ``1`` and ``n`` are given, this returns the star graph on
+      ``n + 1`` nodes.
+
+    See also
+    --------
+
+    complete_bipartite_graph
+
+    """
+    G = nx.empty_graph(sum(block_sizes))
+    # If block_sizes is (n1, n2, n3, ...), create pairs of the form (0, n1),
+    # (n1, n1 + n2), (n1 + n2, n1 + n2 + n3), etc.
+    extents = zip([0] + list(accumulate(block_sizes)), accumulate(block_sizes))
+    blocks = [range(start, end) for start, end in extents]
+    for (i, block) in enumerate(blocks):
+        G.add_nodes_from(block, block=i)
+    # Across blocks, all vertices should be adjacent. We can use
+    # itertools.combinations() because the complete multipartite graph is an
+    # undirected graph.
+    for block1, block2 in itertools.combinations(blocks, 2):
+        G.add_edges_from(itertools.product(block1, block2))
+    G.name = 'complete_multiparite_graph{0}'.format(block_sizes)
+    return G
