@@ -196,11 +196,13 @@ class GEXF(object):
     try: # Python 3.x
         blurb = chr(1245) # just to trigger the exception
         types.extend([
+           (int, "long"),
            (str,"liststring"),
            (str,"anyURI"),
            (str,"string")])
     except ValueError: # Python 2.6+
         types.extend([
+           (long,"long"),
            (str,"liststring"),
            (str,"anyURI"),
            (str,"string"),
@@ -210,7 +212,13 @@ class GEXF(object):
 
     xml_type = dict(types)
     python_type = dict(reversed(a) for a in types)
-    convert_bool={'true':True,'false':False}
+    # http://www.w3.org/TR/xmlschema-2/#boolean
+    convert_bool = {
+        'true': True, 'false': False,
+        'True': True, 'False': False,
+        '0': False, 0: False,
+        '1': False, 1: True
+    }
 
 #    try:
 #        register_namespace = ET.register_namespace
@@ -236,8 +244,7 @@ class GEXF(object):
 class GEXFWriter(GEXF):
     # class for writing GEXF format files
     # use write_gexf() function
-    def __init__(self, graph=None, encoding="utf-8",
-                 mode='static',prettyprint=True,
+    def __init__(self, graph=None, encoding="utf-8", prettyprint=True,
                  version='1.1draft'):
         try:
             import xml.etree.ElementTree
@@ -245,7 +252,6 @@ class GEXFWriter(GEXF):
              raise ImportError('GEXF writer requires '
                                'xml.elementtree.ElementTree')
         self.prettyprint=prettyprint
-        self.mode=mode
         self.encoding = encoding
         self.set_version(version)
         self.xml = Element("gexf",
@@ -277,12 +283,18 @@ class GEXFWriter(GEXF):
         return s
 
     def add_graph(self, G):
+        # set graph attributes
+        if G.graph.get('mode')=='dynamic':
+            mode='dynamic'
+        else:
+            mode='static'
+
         # Add a graph element to the XML
         if G.is_directed():
             default='directed'
         else:
             default='undirected'
-        graph_element = Element("graph",defaultedgetype=default,mode=self.mode)
+        graph_element = Element("graph",defaultedgetype=default,mode=mode)
         self.graph_element=graph_element
         self.add_nodes(G,graph_element)
         self.add_edges(G,graph_element)
@@ -352,12 +364,28 @@ class GEXFWriter(GEXF):
                 kw['type']=make_str(edge_type)
             except KeyError:
                 pass
+            try:
+                start=edge_data.pop('start')
+                kw['start']=make_str(start)
+                self.alter_graph_mode_timeformat(start)
+            except KeyError:
+                pass
+            try:
+                end=edge_data.pop('end')
+                kw['end']=make_str(end)
+                self.alter_graph_mode_timeformat(end)
+            except KeyError:
+                pass
             source_id = make_str(G.node[u].get('id', u))
             target_id = make_str(G.node[v].get('id', v))
             edge_element = Element("edge",
                                    source=source_id,target=target_id,
                                    **kw)
             default=G.graph.get('edge_default',{})
+            if self.version == '1.1':
+                edge_data=self.add_slices(edge_element, edge_data)
+            else:
+                edge_data=self.add_spells(edge_element, edge_data)
             edge_data=self.add_viz(edge_element,edge_data)
             edge_data=self.add_attributes("edge", edge_element,
                                           edge_data, default)
@@ -370,18 +398,23 @@ class GEXFWriter(GEXF):
         attvalues=Element('attvalues')
         if len(data)==0:
             return data
-        if 'start' in data or 'end' in data:
-            mode='dynamic'
-        else:
-            mode='static'
+        mode='static'
         for k,v in data.items():
             # rename generic multigraph key to avoid any name conflict
             if k == 'key':
                 k='networkx_key'
-            attr_id = self.get_attr_id(make_str(k), self.xml_type[type(v)],
-                                       node_or_edge, default, mode)
+            val_type=type(v)
             if type(v)==list:
                 # dynamic data
+                for val,start,end in v:
+                    val_type = type(val)
+                    if start is not None or end is not None:
+                        mode='dynamic'
+                        self.alter_graph_mode_timeformat(start)
+                        self.alter_graph_mode_timeformat(end)
+                        break
+                attr_id = self.get_attr_id(make_str(k), self.xml_type[val_type],
+                                           node_or_edge, default, mode)
                 for val,start,end in v:
                     e=Element("attvalue")
                     e.attrib['for']=attr_id
@@ -393,9 +426,15 @@ class GEXFWriter(GEXF):
                     attvalues.append(e)
             else:
                 # static data
+                mode='static'
+                attr_id = self.get_attr_id(make_str(k), self.xml_type[val_type],
+                                           node_or_edge, default, mode)
                 e=Element("attvalue")
                 e.attrib['for']=attr_id
-                e.attrib['value']=make_str(v)
+                if type(v) == bool:
+                    e.attrib['value']=make_str(v).lower()
+                else:
+                    e.attrib['value']=make_str(v)
                 attvalues.append(e)
         xml_obj.append(attvalues)
         return data
@@ -493,30 +532,46 @@ class GEXFWriter(GEXF):
             node_element.append(parents_element)
         return node_data
 
-    def add_slices(self,node_element,node_data):
-        slices=node_data.pop('slices',False)
+    def add_slices(self,node_or_edge_element,node_or_edge_data):
+        slices=node_or_edge_data.pop('slices',False)
         if slices:
             slices_element=Element('slices')
             for start,end in slices:
                 e=Element('slice',start=str(start),end=str(end))
                 slices_element.append(e)
-            node_element.append(slices_element)
-        return node_data
+            node_or_edge_element.append(slices_element)
+        return node_or_edge_data
 
 
-    def add_spells(self,node_element,node_data):
-        spells=node_data.pop('spells',False)
+    def add_spells(self,node_or_edge_element,node_or_edge_data):
+        spells=node_or_edge_data.pop('spells',False)
         if spells:
             spells_element=Element('spells')
             for start,end in spells:
                 e=Element('spell')
                 if start is not None:
                     e.attrib['start']=make_str(start)
+                    self.alter_graph_mode_timeformat(start)
                 if end is not None:
                     e.attrib['end']=make_str(end)
+                    self.alter_graph_mode_timeformat(end)
                 spells_element.append(e)
-            node_element.append(spells_element)
-        return node_data
+            node_or_edge_element.append(spells_element)
+        return node_or_edge_data
+
+
+    def alter_graph_mode_timeformat(self, start_or_end):
+        # if 'start' or 'end' appears, alter Graph mode to dynamic and set timeformat
+        if self.graph_element.get('mode') == 'static':
+            if start_or_end is not None:
+                if type(start_or_end) == str:
+                    timeformat = 'date'
+                elif type(start_or_end) == float:
+                    timeformat = 'double'
+                elif type(start_or_end) == int:
+                    timeformat = 'long'
+                self.graph_element.set('timeformat', timeformat)
+                self.graph_element.set('mode', 'dynamic')
 
 
     def write(self, fh):
@@ -524,9 +579,7 @@ class GEXFWriter(GEXF):
         if self.prettyprint:
             self.indent(self.xml)
         document = ElementTree(self.xml)
-        header='<?xml version="1.0" encoding="%s"?>'%self.encoding
-        fh.write(header.encode(self.encoding))
-        document.write(fh, encoding=self.encoding)
+        document.write(fh, encoding=self.encoding, xml_declaration=True)
 
 
     def indent(self, elem, level=0):
@@ -575,10 +628,6 @@ class GEXFReader(GEXF):
 
 
     def make_graph(self, graph_xml):
-        # mode is "static" or "dynamic"
-        graph_mode = graph_xml.get("mode", "")
-        self.dynamic=(graph_mode=='dynamic')
-
         # start with empty DiGraph or MultiDiGraph
         edgedefault = graph_xml.get("defaultedgetype", None)
         if edgedefault=='directed':
@@ -593,6 +642,16 @@ class GEXFReader(GEXF):
         graph_end=graph_xml.get('end')
         if graph_end is not None:
             G.graph['end']=graph_end
+        graph_mode=graph_xml.get("mode", "")
+        if graph_mode=='dynamic':
+            G.graph['mode']='dynamic'
+        else:
+            G.graph['mode']='static'
+
+        # timeformat
+        self.timeformat=graph_xml.get('timeformat')
+        if self.timeformat == 'date':
+            self.timeformat = 'string'
 
         # node and edge attributes
         attributes_elements=graph_xml.findall("{%s}attributes"%self.NS_GEXF)
@@ -681,12 +740,13 @@ class GEXFReader(GEXF):
 
     def add_start_end(self, data, xml):
         # start and end times
+        ttype = self.timeformat
         node_start = xml.get("start")
         if node_start is not None:
-            data['start']=node_start
+            data['start']=self.python_type[ttype](node_start)
         node_end = xml.get("end")
         if node_end is not None:
-            data['end']=node_end
+            data['end']=self.python_type[ttype](node_end)
         return data
 
 
@@ -739,8 +799,8 @@ class GEXFReader(GEXF):
                 data['parents'].append(parent)
         return data
 
-    def add_slices(self, data,  node_xml):
-        slices_element=node_xml.find("{%s}slices"%self.NS_GEXF)
+    def add_slices(self, data,  node_or_edge_xml):
+        slices_element=node_or_edge_xml.find("{%s}slices"%self.NS_GEXF)
         if slices_element is not None:
             data['slices']=[]
             for s in slices_element.findall("{%s}slice"%self.NS_GEXF):
@@ -749,13 +809,14 @@ class GEXFReader(GEXF):
                 data['slices'].append((start,end))
         return data
 
-    def add_spells(self, data,  node_xml):
-        spells_element=node_xml.find("{%s}spells"%self.NS_GEXF)
+    def add_spells(self, data,  node_or_edge_xml):
+        spells_element=node_or_edge_xml.find("{%s}spells"%self.NS_GEXF)
         if spells_element is not None:
             data['spells']=[]
+            ttype = self.timeformat
             for s in spells_element.findall("{%s}spell"%self.NS_GEXF):
-                start=s.get('start')
-                end=s.get('end')
+                start=self.python_type[ttype](s.get('start'))
+                end=self.python_type[ttype](s.get('end'))
                 data['spells'].append((start,end))
         return data
 
@@ -782,6 +843,11 @@ class GEXFReader(GEXF):
         data = self.decode_attr_elements(edge_attr, edge_element)
         data = self.add_start_end(data,edge_element)
 
+        if self.version=='1.1':
+            data = self.add_slices(data, edge_element)  # add slices
+        else:
+            data = self.add_spells(data, edge_element)  # add spells
+
         # GEXF stores edge ids as an attribute
         # NetworkX uses them as keys in multigraphs
         # if networkx_key is not specified as an attribute
@@ -833,8 +899,9 @@ class GEXFReader(GEXF):
                 if gexf_keys[key]['mode']=='dynamic':
                     # for dynamic graphs use list of three-tuples
                     # [(value1,start1,end1), (value2,start2,end2), etc]
-                    start=a.get('start')
-                    end=a.get('end')
+                    ttype = self.timeformat
+                    start=self.python_type[ttype](a.get('start'))
+                    end=self.python_type[ttype](a.get('end'))
                     if title in attr:
                         attr[title].append((value,start,end))
                     else:
