@@ -1,5 +1,6 @@
+#  -*- coding: utf-8 -*-
 import json
-from nose.tools import assert_equal, assert_raises, assert_not_equal,assert_true
+from nose.tools import assert_equal, assert_raises, assert_not_equal, assert_true, raises
 import networkx as nx
 from networkx.readwrite.json_graph import *
 
@@ -22,10 +23,10 @@ class TestNodeLink:
         assert_equal(H.node[1]['color'],'red')
         assert_equal(H[1][2]['width'],7)
 
-        d=json.dumps(node_link_data(G))
+        d = json.dumps(node_link_data(G))
         H = node_link_graph(json.loads(d))
         assert_equal(H.graph['foo'],'bar')
-        assert_equal(H.graph[1],'one')
+        assert_equal(H.graph['1'],'one')
         assert_equal(H.node[1]['color'],'red')
         assert_equal(H[1][2]['width'],7)
 
@@ -42,3 +43,22 @@ class TestNodeLink:
         H = node_link_graph(node_link_data(G))
         nx.is_isomorphic(G,H)
         assert_equal(H[1][2]['second']['color'],'blue')
+
+    def test_unicode_keys(self):
+        try:
+            q = unicode("qualité",'utf-8')
+        except NameError:
+            q = "qualité"
+        G = nx.Graph()
+        G.add_node(1, {q:q})
+        s = node_link_data(G)
+        output = json.dumps(s, ensure_ascii=False)
+        data = json.loads(output)
+        H = node_link_graph(data)
+        assert_equal(H.node[1][q], q)
+
+    @raises(nx.NetworkXError)
+    def test_exception(self):
+        G = nx.MultiDiGraph()
+        attrs = dict(id='id', source='node', target='node', key='node')
+        node_link_data(G, attrs)
