@@ -6,7 +6,6 @@ def assert_nodes_equal(nlist1, nlist2):
     # Assumes lists are either nodes, or (node,datadict) tuples,
     # and also that nodes are orderable/sortable.
     try:
-        l = len(nlist1[0])
         n1 = sorted(nlist1,key=operator.itemgetter(0))
         n2 = sorted(nlist2,key=operator.itemgetter(0))
         assert_equal(len(n1),len(n2))
@@ -46,10 +45,10 @@ def assert_graphs_equal(graph1, graph2):
         edges1 = graph1.edges(data=True,keys=True)
     else:
         edges1 = graph1.edges(data=True)
-        if graph2.is_multigraph():
-            edges2 = graph2.edges(data=True,keys=True)
-        else:
-            edges2 = graph2.edges(data=True)
+    if graph2.is_multigraph():
+        edges2 = graph2.edges(data=True,keys=True)
+    else:
+        edges2 = graph2.edges(data=True)
     assert_nodes_equal(graph1.nodes(data=True),
                        graph2.nodes(data=True))
     assert_edges_equal(edges1, edges2)
