@@ -7,18 +7,18 @@ Do not add this file to the repository.
 
 import datetime
 
-version = '1.8.1'
-date = 'Sun Aug  4 07:56:54 2013'
+version = '1.11'
+date = 'Sat Jan 30 09:55:40 2016'
 
 # Was NetworkX built from a development version? If so, remember that the major
 # and minor versions reference the "target" (rather than "current") release.
 dev = False
 
 # Format: (name, major, min, revision)
-version_info = ('networkx', '1', '8.1', None)
+version_info = ('networkx', '1', '11', None)
 
 # Format: a 'datetime.datetime' instance
-date_info = datetime.datetime(2013, 8, 4, 7, 56, 54, 416491)
+date_info = datetime.datetime(2016, 1, 30, 9, 55, 40, 165755)
 
 # Format: (vcs, vcs_tuple)
 vcs_info = (None, (None, None))
